@@ -108,6 +108,22 @@ class Retrievable(Resource):
         response = client.get(f'/{cls._resource}/{id}/apikeys/{env}')
         return response
 
+    @classmethod
+    def _tax_info_validation(cls, id: str) -> Resource:
+        """Retrieve a resource given its ID
+
+        Performs a GET request with the ID.
+
+        Args:
+            id: The ID of the resource
+
+        Returns:
+            Resource: The resource retrieved.
+
+        """
+        response = client.get(f'/{cls._resource}/{id}/tax-info-validation')
+        return cls._from_dict(response)
+
     def refresh(self):
         """Refresh a resource
 
@@ -147,7 +163,7 @@ class Downloadable(Resource):
 
         """
         return client.download_request(
-            f'/{cls._resource}/{id}/{file_type.value}'
+            f'/{cls._resource}/{id}/{file_type}'
         )
 
 
