@@ -8,6 +8,11 @@ class FileType(str, Enum):
     xml = 'xml'
     zip = 'zip'
 
+class Steps(str,Enum):
+    legal = "legal"
+    logo = "logo"
+    certificate = "certificate"
+
 
 class InvoiceRelation(str, Enum):
     """Relation key in SAT catalogue for related invoices."""
@@ -57,9 +62,7 @@ class InvoiceUse(str, Enum):
     gastos_transportacion_escolar = 'D08'
     cuentas_ahorro_pensiones = 'D09'
     servicios_educativos = 'D10'
-    sin_efectos_fiscales = 'S01'
-    pagos = 'CP01'
-    nomina = 'CN01'
+    por_definir = 'P01'
 
 
 class PaymentForm(str, Enum):
