@@ -115,6 +115,29 @@ class SanitizedDict(dict):
         super().__init__(*args, **kwargs)
         sanitize_dict(self)
 
+class OrganizationAddress(BaseModel):
+    """Address of an organization.
+
+    Attributes:
+        zip (str): Postal code.
+        street (str): Street.
+        exterior (str): Exterior place number.
+        interior (str): Interior place number.
+        neighborhood (str): 'Colonia'.
+        city (str): City.
+        municipality (str): 'Municipio or Alcaldía'.
+        state (str): State of the address.
+    """
+
+    zip: str
+    street: str
+    exterior: str
+    interior: Optional[str]
+    neighborhood: Optional[str]
+    city: Optional[str]
+    municipality: Optional[str]
+    state: Optional[str]
+
 
 
 
